getClip method

  1. @override
Path getClip(
  1. Size size
)
override

Returns a description of the clip given that the render object being clipped is of the given size.

Implementation

@override
Path getClip(Size size) {
  final path = Path();
  final w = size.width;
  final h = size.height;

  final indentation = w * cutRatio;

  path.moveTo(0, 0);

  path.lineTo(w, 0);

  path.lineTo(w - indentation, h / 2);

  path.lineTo(w, h);

  path.lineTo(0, h);

  path.lineTo(indentation, h / 2);

  path.close();

  return path;
}