getClip method
Returns a description of the clip given that the render object being clipped is of the given size.
Implementation
@override
Path getClip(Size size) {
final path = Path();
path.moveTo(size.width * 0.2, size.height * 0.1);
path.quadraticBezierTo(
size.width * 0.4,
size.height * 0.0,
size.width * 0.6,
size.height * 0.15,
);
path.quadraticBezierTo(
size.width * 0.85,
size.height * 0.3,
size.width * 0.75,
size.height * 0.6,
);
path.quadraticBezierTo(
size.width * 0.7,
size.height * 0.85,
size.width * 0.45,
size.height * 0.8,
);
path.quadraticBezierTo(
size.width * 0.1,
size.height * 0.75,
size.width * 0.15,
size.height * 0.35,
);
path.quadraticBezierTo(
size.width * 0.15,
size.height * 0.2,
size.width * 0.2,
size.height * 0.1,
);
path.close();
return path;
}